@@ -12,7 +12,7 @@ use File::Temp;
 #require ExtUtils::MM;
 use Archive::Zip;
 
-our $VERSION = '0.18';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -59,19 +59,18 @@ the directory name. Returns the empty list on failure.
 =cut
 
 sub _unzip_dist_to_path {
-  my $self = shift;
-  $self->verbose(2, "Entering _unzip_to_path()");
-  my $dist = shift;
-  my $path = shift || File::Spec->curdir;
-  return unless -f $dist;
+	my $self = shift;
+	$self->verbose(2, "Entering _unzip_to_path()");
+    my $dist = shift;
+    my $path = shift || File::Spec->curdir;
+    return unless -f $dist;
 
-  my $zip = Archive::Zip->new;
-  local %SIG;
-  $SIG{__WARN__} = sub { print STDERR $_[0] unless $_[0] =~ /\bstat\b/ };
-  return
-    unless $zip->read($dist) == Archive::Zip::AZ_OK()
-           and $zip->extractTree('', "$path/") == Archive::Zip::AZ_OK();
-  return $path;
+    my $zip = Archive::Zip->new;
+    local %SIG;
+    $SIG{__WARN__} = sub { print STDERR $_[0] unless $_[0] =~ /\bstat\b/ };
+    return unless $zip->read($dist) == Archive::Zip::AZ_OK()
+              and $zip->extractTree('', "$path/") == Archive::Zip::AZ_OK();
+    return $path;
 }
 
 =head2 _unzip_dist_to_tmpdir
@@ -84,17 +83,17 @@ C<blib/> sub directories.
 =cut
 
 sub _unzip_dist_to_tmpdir {
-  my $self = shift;
-  $self->verbose(2, "Entering _unzip_dist_to_tmpdir()");
-  my $dist   = File::Spec->rel2abs(shift);
-  my $subdir = shift;
-  my $tmpdir = File::Temp::mkdtemp(File::Spec->catdir(File::Spec->tmpdir, "parXXXXX")) or die $!;
-  my $path = $tmpdir;
-  $path = File::Spec->catdir($tmpdir, $subdir) if defined $subdir;
-  $self->_unzip_dist_to_path($dist, $path);
+	my $self = shift;
+	$self->verbose(2, "Entering _unzip_dist_to_tmpdir()");
+    my $dist   = File::Spec->rel2abs(shift);
+	my $subdir = shift;
+    my $tmpdir = File::Temp::mkdtemp(File::Spec->catdir(File::Spec->tmpdir, "parXXXXX")) or die $!;
+    my $path = $tmpdir;
+    $path = File::Spec->catdir($tmpdir, $subdir) if defined $subdir;
+    $self->_unzip_dist_to_path($dist, $path);
 
-  chdir $tmpdir;
-  return ($dist, $tmpdir);
+    chdir $tmpdir;
+    return ($dist, $tmpdir);
 }
 
 =head2 _zip_file
@@ -112,20 +111,19 @@ Optional third argument is the zip member name to use.
 =cut
 
 sub _zip_file {
-  my $class = shift;
-  my $file = shift;
-  return unless -f $file;
-  my $target = shift;
-  my $member_name = shift;
-  $member_name = $file if not defined $member_name;
-  $target = $file.'.zip' if not defined $target;
+	my $class = shift;
+	my $file = shift;
+	return unless -f $file;
+	my $target = shift;
+	my $member = shift;
+	$member = $file if not defined $member;
+	$target = $file.'.zip' if not defined $target;
 
-  my $zip = Archive::Zip->new;
-  my $member = $zip->addFile( $file, $member_name );
-  $member->desiredCompressionLevel( Archive::Zip::COMPRESSION_LEVEL_BEST_COMPRESSION() );
-  $zip->writeToFileNamed( $target ) == Archive::Zip::AZ_OK() or die $!;
-  
-  return $target;
+	my $zip = Archive::Zip->new;
+    $zip->addFile( $file, $member );
+    $zip->writeToFileNamed( $target ) == Archive::Zip::AZ_OK() or die $!;
+    
+	return $target;
 }
 
 =head2 _unzip_file
@@ -141,21 +139,21 @@ Returns the name of the unzipped file.
 =cut
 
 sub _unzip_file {
-  my $class = shift;
-  my $file = shift;
-  my $target = shift;
-  my $member = shift;
-  $member = $target if not defined $member;
-  return unless -f $file;
+	my $class = shift;
+	my $file = shift;
+	my $target = shift;
+	my $member = shift;
+	$member = $target if not defined $member;
+	return unless -f $file;
 
-  my $zip = Archive::Zip->new;
-  local %SIG;
-  $SIG{__WARN__} = sub { print STDERR $_[0] unless $_[0] =~ /\bstat\b/ };
-      
-  return unless $zip->read($file) == Archive::Zip::AZ_OK()
-         and $zip->extractMember($member, $target) == Archive::Zip::AZ_OK();
+    my $zip = Archive::Zip->new;
+	local %SIG;
+	$SIG{__WARN__} = sub { print STDERR $_[0] unless $_[0] =~ /\bstat\b/ };
+	
+    return unless $zip->read($file) == Archive::Zip::AZ_OK()
+           and $zip->extractMember($member, $target) == Archive::Zip::AZ_OK();
 
-  return $target;
+	return $target;
 }
 
 
@@ -169,7 +167,7 @@ Steffen Müller, E<lt>smueller@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Steffen Müller
+Copyright (C) 2006 by Steffen Müller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.6 or,
